@@ -12,24 +12,15 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-import datetime
 import re
 
 from tibiawikisql import schema
 from tibiawikisql.models import abc
-from tibiawikisql.utils import parse_boolean, parse_integer
-
-
-def parse_date(value):
-    try:
-        return datetime.datetime.strptime(value, "%B %d, %Y").date().isoformat()
-    except ValueError:
-        return datetime.datetime.strptime(value, "%b %d, %Y").date().isoformat()
+from tibiawikisql.utils import parse_boolean, parse_integer, parse_date
 
 
 class World(abc.Row, abc.Parseable, table=schema.World):
-    """
-    Represents a Game World.
+    """Represents a Game World.
 
     Attributes
     ----------
@@ -57,6 +48,8 @@ class World(abc.Row, abc.Parseable, table=schema.World):
         The name of the world this world got merged into, if applicable.
     battleye: :class:`bool`
         Whether the world is BattlEye protected or not.
+    battleye_type: :class:`bool`
+        The type of BattlEye protection the world has. Can be either green or yellow.
     protected_since: :class:`str`
         Date when the world started being protected by BattlEye, in ISO 8601 format.
     world_board: :class:`int`
@@ -74,6 +67,7 @@ class World(abc.Row, abc.Parseable, table=schema.World):
         "offline": ("offline_since", parse_date),
         "mergedinto": ("merged_into", str.strip),
         "battleye": ("battleye", parse_boolean),
+        "battleyetype": ("battleye_type", str.strip),
         "protectedsince": ("protected_since", parse_date),
         "worldboardid": ("world_board", parse_integer),
         "tradeboardid": ("trade_board", parse_integer),
@@ -93,6 +87,7 @@ class World(abc.Row, abc.Parseable, table=schema.World):
         "offline_since",
         "merged_into",
         "battleye",
+        "battleye_type",
         "protected_since",
         "world_board",
         "trade_board"
