@@ -48,6 +48,7 @@ class Creature(Table):
     title = Column(Text, unique=True, no_case=True)
     name = Column(Text, no_case=True, index=True)
     plural = Column(Text)
+    library_race = Column(Text)
     article = Column(Text)
     hitpoints = Column(Integer)
     experience = Column(Integer)
@@ -60,6 +61,7 @@ class Creature(Table):
     bestiary_level = Column(Text, index=True)
     bestiary_occurrence = Column(Text, index=True)
     max_damage = Column(Integer)
+    runs_at = Column(Integer)
     summon_cost = Column(Integer)
     convince_cost = Column(Integer)
     illusionable = Column(Boolean)
@@ -77,9 +79,11 @@ class Creature(Table):
     modifier_holy = Column(Integer)
     modifier_drown = Column(Integer)
     modifier_hpdrain = Column(Integer)
+    modifier_healing = Column(Integer)
     abilities = Column(Text)
     walks_through = Column(Text)
     walks_around = Column(Text)
+    location = Column(Text)
     version = Column(Text, index=True)
     image = Column(Blob)
     status = Column(Text, default="active")
@@ -169,6 +173,7 @@ class Imbuement(Table):
     tier = Column(Text)
     type = Column(Text)
     effect = Column(Text)
+    slots = Column(Text)
     version = Column(Text, index=True)
     image = Column(Blob)
     status = Column(Text, default="active")
@@ -208,14 +213,19 @@ class Spell(Table):
     words = Column(Text, index=True)
     effect = Column(Text)
     type = Column(Text, index=True)
-    classz = Column(Text, name="class", index=True)
+    group_spell = Column(Text, index=True)
+    group_secondary = Column(Text, index=True)
+    group_rune = Column(Text, index=True)
     element = Column(Text, index=True)
     level = Column(Integer)
     mana = Column(Integer)
     soul = Column(Integer, default=0)
-    premium = Column(Integer)
+    premium = Column(Boolean)
+    promotion = Column(Boolean, default=False)
     price = Column(Integer)
     cooldown = Column(Integer)
+    cooldown_group = Column(Integer)
+    cooldown_group_secondary = Column(Integer)
     knight = Column(Boolean, default=False)
     sorcerer = Column(Boolean, default=False)
     druid = Column(Boolean, default=False)
@@ -235,6 +245,7 @@ class Npc(Table):
     city = Column(Text, index=True)
     location = Column(Text)
     job = Column(Text)
+    job_additionals = Column(Text)
     version = Column(Text, index=True)
     x = Column(Integer)
     y = Column(Integer)
@@ -352,6 +363,7 @@ class World(Table):
     offline_since = Column(Text)
     merged_into = Column(Text)
     battleye = Column(Boolean, default=False)
+    battleye_type = Column(Text, index=True)
     protected_since = Column(Text)
     world_board = Column(Integer)
     trade_board = Column(Integer)
@@ -375,6 +387,22 @@ class Mount(Table):
     timestamp = Column(Integer)
 
 
+class Update(Table, table_name="game_update"):
+    article_id = Column(Integer, primary_key=True)
+    title = Column(Text, unique=True, no_case=True)
+    name = Column(Text, no_case=True, index=True)
+    date = Column(Text, index=True)
+    news_id = Column(Integer, index=True)
+    type_primary = Column(Text, index=True)
+    type_secondary = Column(Text, index=True)
+    previous = Column(Text, index=True)
+    next = Column(Text, index=True)
+    version = Column(Text, index=True)
+    summary = Column(Text, index=True)
+    changes = Column(Text, index=True)
+    timestamp = Column(Integer)
+
+
 def create_tables(conn):
     """
     Creates all the tables in the database.
